# Infrared glass

Often, calcogenide glasses are used in the optical systems operating at infrared wavelengths ~1-14 µm (for instance, optical systems for thermal imaging and night vision)

## Infrared glass types/brands from different makers

- AMTIR (an acronym for "Amorphous Material Transmitting Infrared Radiation"): Amorphous Materials Inc. (AMI)
- IG: VITRON
- IRG: SCHOTT
- BD: LightPath
- OPTIR: Rochester Precision Optics (RPO)

## Cross-reference

Composition | AMI | VITRON | SCHOTT | LightPath | RPO
--- | --- | --- | --- | --- | ---
Ge33As12Se55 | AMTIR-1 | IG 2 | IRG 22 |  | OPTIR-1
Ge30Sb13Se32Te25 |  | IG 3 | IRG 23 |  |
Ge10As40Se50 |  | IG 4 | IRG 24 |  |
Ge28Sb12Se60 | AMTIR-3* | IG 5 | IRG 25 | BD-2 | OPTIR-3
As40Se60 | AMTIR-2 | IG 6 | IRG 26 |  |
As40S60 | AMTIR-6 |  |  |  |

(*) Out of production

## External Links

- Infrared - Wikipedia
- Chalcogenide glass - Wikipedia
- AMTIR amorphous material transmitting IR radiation - Amorphous Materials
- Brief introduction: chalcogenide glasses - VITRON
- Infrared Chalcogenide Glasses - SCHOTT
- Products overview - LightPath
- Optir-1™ & Optir-3™ Properties - Rochester Precision Optics